@@ -8,7 +8,6 @@ from django.contrib.admin import helpers
 from django.contrib.admin.views import main as main_views
 from django.shortcuts import render_to_response
 from django.template import RequestContext
-from django.utils.encoding import force_unicode
 from django.utils.html import escape
 from django.utils.translation import ugettext_lazy as _
 
@@ -22,6 +21,11 @@ from .models import (TaskState, WorkerState,
                      PeriodicTask, IntervalSchedule, CrontabSchedule)
 from .humanize import naturaldate
 
+try:
+    from django.utils.encoding import force_text
+except ImportError:
+    from django.utils.encoding import force_unicode as force_text
+
 
 TASK_STATE_COLORS = {states.SUCCESS: 'green',
                      states.FAILURE: 'red',
@@ -175,7 +179,7 @@ class TaskMonitor(ModelMonitor):
         context = {
             'title': _('Rate limit selection'),
             'queryset': queryset,
-            'object_name': force_unicode(opts.verbose_name),
+            'object_name': force_text(opts.verbose_name),
             'action_checkbox_name': helpers.ACTION_CHECKBOX_NAME,
             'opts': opts,
             'app_label': app_label,
