@@ -5,7 +5,7 @@ from pprint import pformat
 from django.utils.html import escape
 
 FIXEDWIDTH_STYLE = '''\
-<span title="%s", style="font-size: %spt; \
+<span title="%s" style="font-size: %spt; \
 font-family: Menlo, Courier; ">%s</span> \
 '''
 
@@ -18,8 +18,8 @@ def attrs(**kwargs):
     return _inner
 
 
-def display_field(short_description, admin_order_field, allow_tags=True,
-        **kwargs):
+def display_field(short_description, admin_order_field,
+                  allow_tags=True, **kwargs):
     return attrs(short_description=short_description,
                  admin_order_field=admin_order_field,
                  allow_tags=allow_tags, **kwargs)
@@ -38,12 +38,12 @@ def fixedwidth(field, name=None, pt=6, width=16, maxlen=64, pretty=False):
             val = pformat(val, width=width)
         if val.startswith("u'") or val.startswith('u"'):
             val = val[2:-1]
-        shortval = val.replace(",", ",\n")
-        shortval = shortval.replace("\n", "|br/|")
+        shortval = val.replace(',', ',\n')
+        shortval = shortval.replace('\n', '|br/|')
 
         if len(shortval) > maxlen:
-            shortval = shortval[:maxlen] + "..."
+            shortval = shortval[:maxlen] + '...'
         styled = FIXEDWIDTH_STYLE % (escape(val[:255]), pt,
                                      escape(shortval))
-        return styled.replace("|br/|", "<br/>")
+        return styled.replace('|br/|', '<br/>')
     return f
