@@ -6,7 +6,8 @@ from djcelery.views import apply
 # from django.contrib import admin
 # admin.autodiscover()
 
-urlpatterns = patterns('',
+urlpatterns = patterns(
+    '',
     # Example:
     # (r'^tests/', include('tests.foo.urls')),
 
@@ -16,7 +17,7 @@ urlpatterns = patterns('',
 
     # Uncomment the next line to enable the admin:
     # (r'^admin/(.*)', admin.site.root),
-    url(r"^apply/(?P<task_name>.+?)/", apply, name="celery-apply"),
-    url(r"^celery/", include("djcelery.urls")),
+    url(r'^apply/(?P<task_name>.+?)/', apply, name='celery-apply'),
+    url(r'^celery/', include('djcelery.urls')),
 
 )
